@@ -65,7 +65,6 @@ print config['value']
 config.generate_config()
 
 
-:version:   $Revision: 1.40 $  
 :author:    Logilab
 :copyright: 2003-2006 LOGILAB S.A. (Paris, FRANCE)
 :contact:   http://www.logilab.fr/ -- mailto:python-projects@logilab.org
@@ -314,7 +313,7 @@ class OptionsManagerMixIn(object):
     
     def __init__(self, usage, config_file=None, version=None, quiet=0):
         self.config_file = config_file
-        self.reset_parsers(usage, version=None)
+        self.reset_parsers(usage, version=version)
         # list of registered options providers
         self.options_providers = []
         # dictionary assocating option name to checker
@@ -481,17 +480,19 @@ class OptionsManagerMixIn(object):
                 if onlysection is not None and section != onlysection:
                     continue
                 default = provider.option_default(option, optdict)
-                if default is REQUIRED:
-                    defaultstr = 'required'
+                if optdict['type'] == 'password':
+                    defaultstr = ': '
+                elif default is REQUIRED:
+                    defaultstr = '(required): '
                 else:
                     if optdict.get('inputlevel', 0) > inputlevel:
                         provider.set_option(option, default, opt_dict=optdict)
                         continue
-                    defaultstr = 'default: %s' % format_option_value(optdict, default)
+                    defaultstr = '(default: %s): ' % format_option_value(optdict, default)
                 print ':%s:' % option
                 print optdict.get('help') or option
                 inputfunc = INPUT_FUNCTIONS[optdict['type']]
-                value = inputfunc(optdict, '(%s): ' % defaultstr)
+                value = inputfunc(optdict, defaultstr)
                 while default is REQUIRED and not value:
                     print 'please specify a value'
                     value = inputfunc(optdict, '%s: ' % option)
@@ -811,12 +812,11 @@ def read_old_config(newconfig, changes, configfile):
     possible changes:
     * ('renamed', oldname, newname)
     * ('moved', option, oldgroup, newgroup)
+    * ('typechanged', option, oldtype, newvalue)
     """
     # build an index of changes
     changesindex = {}
     for action in changes:
-        if action[0] not in ('moved', 'renamed'):
-            raise Exception('unknown change %s' % action[0])
         if action[0] == 'moved':
             option, oldgroup, newgroup = action[1:]
             changesindex.setdefault(option, []).append((action[0], oldgroup, newgroup))
@@ -825,6 +825,10 @@ def read_old_config(newconfig, changes, configfile):
             oldname, newname = action[1:]
             changesindex.setdefault(newname, []).append((action[0], oldname))
             continue
+        if action[0] == 'typechanged':
+            option, oldtype, newvalue = action[1:]
+            changesindex.setdefault(option, []).append((action[0], oldtype, newvalue))
+            continue        
         if action[1] in ('added', 'removed'):
             continue # nothing to do here
         raise Exception('unknown change %s' % action[0])    
@@ -838,6 +842,10 @@ def read_old_config(newconfig, changes, configfile):
                 optdef['group'] = oldgroup
             elif action[0] == 'renamed':
                 optname = action[1]
+            elif action[0] == 'typechanged':
+                oldtype = action[1]
+                optdef = optdef.copy()
+                optdef['type'] = oldtype
         options.append((optname, optdef))
     if changesindex:
         raise Exception('unapplied changes: %s' % changesindex)
@@ -852,11 +860,13 @@ def read_old_config(newconfig, changes, configfile):
             oldname, newname = action[1:]
             newconfig[newname] = oldconfig[oldname]
             done.add(newname)
-            continue
+        elif action[0] == 'typechanged':
+            optname, oldtype, newvalue = action[1:]
+            newconfig[optname] = newvalue
+            done.add(optname)
     for optname, optdef in newconfig.options:
-        if optname in done:
-            continue
-        newconfig.set_option(optname, oldconfig[optname], opt_dict=optdef)
+        if not optname in done:
+            newconfig.set_option(optname, oldconfig[optname], opt_dict=optdef)
 
 
 def merge_options(options):
