@@ -230,6 +230,16 @@ class _Psycopg2Adapter(_PsycopgAdapter):
             extensions.register_type(psycopg2._psycopg.MXINTERVAL)
             extensions.register_type(psycopg2._psycopg.MXDATE)
             extensions.register_type(psycopg2._psycopg.MXTIME)
+            # StringIO/cStringIO adaptation
+            # XXX (syt) todo, see my december discussion on the psycopg2 list
+            # for a working solution
+            #def adapt_stringio(stringio):
+            #    print 'ADAPTING', stringio
+            #    return psycopg2.Binary(stringio.getvalue())
+            #import StringIO
+            #extensions.register_adapter(StringIO.StringIO, adapt_stringio)
+            #import cStringIO
+            #extensions.register_adapter(cStringIO.StringIO, adapt_stringio)
         
 
 class _PgsqlAdapter(DBAPIAdapter):
@@ -373,7 +383,7 @@ class _MySqlDBAdapter(DBAPIAdapter):
         the unicode named argument asks to use Unicode objects for strings
         in result sets and query parameters
         """
-        kwargs = {'host' : host, 'db' : database,
+        kwargs = {'host' : host or '', 'db' : database,
                   'user' : user, 'passwd' : password,
                   'use_unicode' : unicode}
         if port:
@@ -442,10 +452,22 @@ INSERT INTO %s VALUES (0);''' % (seq_name, seq_name)
         return "CREATE TEMPORARY TABLE %s (%s);" % (table_name,
                                                     table_schema)
     
+    def sql_drop_unique_constraint(self, table, column):
+        # XXX postgres specific ?
+        return 'ALTER TABLE %s DROP CONSTRAINT %s_%s_key' % (
+            table, table, column)
+    
     def increment_sequence(self, cursor, seq_name):
         for sql in self.sqls_increment_sequence(seq_name):
             cursor.execute(sql)
         return cursor.fetchone()[0]
+    
+    def list_users(self, cursor, username=None):
+        if not self.support_users():
+            return None
+        if username is None:
+            return ()
+        return None
 
     
 class _PGAdvFuncHelper(_GenericAdvFuncHelper):
@@ -506,6 +528,12 @@ class _PGAdvFuncHelper(_GenericAdvFuncHelper):
         return "CREATE TEMPORARY TABLE %s (%s) ON COMMIT DROP;" % (table_name,
                                                                    table_schema)
 
+    def list_users(self, cursor, username=None):
+        if username is None:
+            return cursor.execute("SELECT usename FROM pg_user")
+        return cursor.execute("SELECT usename FROM pg_user WHERE usename=%(user)s",
+                              {'user': username})
+
 def dbcmd(cmd, dbhost, dbuser):
     cmd = [cmd]
     if dbhost:
@@ -539,7 +567,7 @@ class _SqliteAdvFuncHelper(_GenericAdvFuncHelper):
 PREFERED_DRIVERS = {
     "postgres" : [ 'psycopg2', 'psycopg', 'pgdb', 'pyPgSQL.PgSQL', ],
     "mysql" : [ 'MySQLdb', ], # 'pyMySQL.MySQL, ],
-    "sqlite" : [ 'pysqlite2.dbapi2', 'sqlite', ],
+    "sqlite" : ['sqlite3', 'pysqlite2.dbapi2', 'sqlite', ],
     }
 
 _ADAPTERS = {
@@ -550,7 +578,8 @@ _ADAPTERS = {
                    },
     'mysql' : { 'MySQLdb' : _MySqlDBAdapter, },
     'sqlite' : { 'pysqlite2.dbapi2' : _PySqlite2Adapter,
-                 'sqlite' : _SqliteAdapter, },
+                 'sqlite' : _SqliteAdapter,
+                 'sqlite3' : _PySqlite2Adapter, },
     }
 
 # _AdapterDirectory could be more generic by adding a 'protocol' parameter
