@@ -3,12 +3,18 @@ Unittests for date helpers
 """
 
 from logilab.common.testlib import TestCase, unittest_main
-from logilab.common.date import date_range, endOfMonth
 
-from mx.DateTime import Date, RelativeDate
+from logilab.common.date import date_range
+
+try:
+    from mx.DateTime import Date, RelativeDate
+    from logilab.common.date import endOfMonth
+except ImportError:
+    from datetime import date as Date
+    endOfMonth = None
 
 class DateTC(TestCase):
-
+    
     def test_day(self):
         """enumerate days"""
         r = list(date_range(Date(2000,1,1), Date(2000,1,4)))
@@ -20,6 +26,8 @@ class DateTC(TestCase):
 
     def test_month(self):
         """enumerate months"""
+        if endOfMonth is None:
+            self.skip('mx.DateTime is not installed')
         r = list(date_range(Date(2000,1,2), Date(2000,4,4), endOfMonth))
         expected = [Date(2000,1,2), Date(2000,2,29), Date(2000,3,31)]
         self.assertListEquals(r, expected)
