@@ -1,8 +1,8 @@
 """
 unit tests for module logilab.common.db
-
 """
-__revision__ = "$Id: unittest_db.py,v 1.13 2006-03-13 12:42:56 syt Exp $"
+
+import socket
 
 from logilab.common.testlib import TestCase, unittest_main
 from logilab.common.db import *
@@ -46,9 +46,11 @@ class PreferedDriverTC(TestCase):
         self.assertEquals(PREFERED_DRIVERS['postgres'], expected)
 
 
-class getCnxTC(TestCase):
+class GetCnxTC(TestCase):
     def setUp(self):
-        self.host = None # 'crater.logilab.fr'
+        if not socket.gethostname().startswith('crater'):
+            self.skip("those tests require specific DB configuration")
+        self.host = 'localhost' # None
         self.db = 'template1'
         self.user = 'adim'
         self.passwd = 'adim'
@@ -175,7 +177,10 @@ class DBAPIAdaptersTC(TestCase):
         except ImportError:
             self.skip('postgresql dbapi module not installed')            
         self.failUnless(isinstance(module.adv_func_helper, _PGAdvFuncHelper))
-        module = get_dbapi_compliant_module('sqlite')
+        try:
+            module = get_dbapi_compliant_module('sqlite')
+        except ImportError:
+            self.skip('postgresql dbapi module not installed')            
         self.failUnless(isinstance(module.adv_func_helper, _GenericAdvFuncHelper))
 
 
